==> haskell-unicode-collation-0.1.3.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-collation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-collation
version:              0.1.3.1
visibility:           public
id:                   unicode-collation-0.1.3.1-6X6KQLFRGZZICR5dKy37KI
key:                  unicode-collation-0.1.3.1-6X6KQLFRGZZICR5dKy37KI
license:              BSD-2-Clause
copyright:            2021 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane
homepage:             https://github.com/jgm/unicode-collation
synopsis:             Haskell implementation of the Unicode Collation Algorithm
description:
    This library provides a pure Haskell implementation of
    the Unicode Collation Algorithm described at
    <http://www.unicode.org/reports/tr10/>.  It is not
    as fully-featured or as performant as @text-icu@, but
    it avoids a dependency on a large C library.
    Locale-specific tailorings are also provided.

category:             Text
abi:                  5328015477ac3d7a5d8627f035442f23
exposed:              True
exposed-modules:      Text.Collate Text.Collate.Lang Text.Collate.Normalize
hidden-modules:
    Text.Collate.Trie Text.Collate.Collation Text.Collate.Collator
    Text.Collate.CanonicalCombiningClass Text.Collate.TH
    Text.Collate.Tailorings Text.Collate.UnicodeData

import-dirs:          /usr/lib/ghc-9.0.1/site-local/unicode-collation-0.1.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/unicode-collation-0.1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/unicode-collation-0.1.3.1
hs-libraries:         HSunicode-collation-0.1.3.1-6X6KQLFRGZZICR5dKy37KI
depends:
    base-4.15.0.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 parsec-3.1.14.0 template-haskell-2.17.0.0
    text-1.2.4.1 th-lift-instances-0.1.18-D8xbmf4aEv7KKE6pjHfR6K

haddock-interfaces:
    /usr/share/doc/haskell-unicode-collation/html/unicode-collation.haddock

haddock-html:         /usr/share/doc/haskell-unicode-collation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-collation-0.1.3.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-collation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-collation
version:              0.1.3.1
visibility:           public
id:                   unicode-collation-0.1.3.1-3bZqSrZ2vrr88QX4keufqC
key:                  unicode-collation-0.1.3.1-3bZqSrZ2vrr88QX4keufqC
license:              BSD-2-Clause
copyright:            2021 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane
homepage:             https://github.com/jgm/unicode-collation
synopsis:             Haskell implementation of the Unicode Collation Algorithm
description:
    This library provides a pure Haskell implementation of
    the Unicode Collation Algorithm described at
    <http://www.unicode.org/reports/tr10/>.  It is not
    as fully-featured or as performant as @text-icu@, but
    it avoids a dependency on a large C library.
    Locale-specific tailorings are also provided.

category:             Text
abi:                  0e3231e65cbdc924c8be9abcdf989761
exposed:              True
exposed-modules:      Text.Collate Text.Collate.Lang Text.Collate.Normalize
hidden-modules:
    Text.Collate.Trie Text.Collate.Collation Text.Collate.Collator
    Text.Collate.CanonicalCombiningClass Text.Collate.TH
    Text.Collate.Tailorings Text.Collate.UnicodeData

import-dirs:          /usr/lib/ghc-9.0.1/site-local/unicode-collation-0.1.3.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/unicode-collation-0.1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/unicode-collation-0.1.3.1
hs-libraries:         HSunicode-collation-0.1.3.1-3bZqSrZ2vrr88QX4keufqC
depends:
    base-4.15.0.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 parsec-3.1.14.0 template-haskell-2.17.0.0
    text-1.2.4.1 th-lift-instances-0.1.19-2wg216phHavDGk4KuBqXQq

haddock-interfaces:
    /usr/share/doc/haskell-unicode-collation/html/unicode-collation.haddock

haddock-html:         /usr/share/doc/haskell-unicode-collation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
